=======================
Data Protection service
=======================

.. toctree::
   :maxdepth: 2

   get_started.rst
   install.rst
   verify.rst
   launch-instance.rst
   next-steps.rst

To protect the Data and Metadata that comprises an OpenStack-deployed
Application against loss/damage (e.g. backup, replication), The Data
Protection service (Karbor) provides a standard framework of APIs and
services that allows vendors to provide plugins through a unified interface.

This chapter assumes a working setup of OpenStack following the
`OpenStack Installation Tutorial <https://docs.openstack.org/#install-guides>`_.
